summaryrefslogtreecommitdiffstats
path: root/src/gui/listview.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <[email protected]>2013-02-01 15:06:16 -0600
committerTimothy Pearson <[email protected]>2013-02-01 15:06:16 -0600
commit7717bcec2ad7d94e3f38a2e831bafa60a525f7d2 (patch)
tree77ffa8fe14318bb3a285cae65dbe622bcbbcb3f9 /src/gui/listview.cpp
parentb5cff83092d97189b5a55e1a996995207bc3016c (diff)
downloadtellico-7717bcec2ad7d94e3f38a2e831bafa60a525f7d2.tar.gz
tellico-7717bcec2ad7d94e3f38a2e831bafa60a525f7d2.zip
Rename a number of classes to enhance compatibility with KDE4
Diffstat (limited to 'src/gui/listview.cpp')
-rw-r--r--src/gui/listview.cpp16
1 files changed, 8 insertions, 8 deletions
diff --git a/src/gui/listview.cpp b/src/gui/listview.cpp
index 4b8c250..5c1a38c 100644
--- a/src/gui/listview.cpp
+++ b/src/gui/listview.cpp
@@ -25,7 +25,7 @@
using Tellico::GUI::ListView;
using Tellico::GUI::ListViewItem;
-ListView::ListView(TQWidget* parent_, const char* name_) : KListView(parent_, name_/*=0*/),
+ListView::ListView(TQWidget* parent_, const char* name_) : TDEListView(parent_, name_/*=0*/),
m_sortStyle(SortByText), m_isClear(true) {
setSelectionMode(TQListView::Extended);
connect(this, TQT_SIGNAL(selectionChanged()),
@@ -113,7 +113,7 @@ int ListView::lastVisibleColumn() const {
void ListView::setColumnText(int column, const TQString& label) {
ListViewComparison* comp = m_comparisons.take(columnText(column));
- KListView::setColumnText(column, label);
+ TDEListView::setColumnText(column, label);
if(comp) {
m_comparisons.insert(columnText(column), comp);
}
@@ -227,7 +227,7 @@ void ListView::slotDoubleClicked(TQListViewItem* item_) {
void ListView::drawContentsOffset(TQPainter* p, int ox, int oy, int cx, int cy, int cw, int ch) {
bool oldUpdatesEnabled = isUpdatesEnabled();
setUpdatesEnabled(false);
- KListView::drawContentsOffset(p, ox, oy, cx, cy, cw, ch);
+ TDEListView::drawContentsOffset(p, ox, oy, cx, cy, cw, ch);
setUpdatesEnabled(oldUpdatesEnabled);
}
@@ -259,7 +259,7 @@ int ListViewItem::compare(TQListViewItem* item_, int col_, bool asc_) const {
return res;
}
res = listView()->compare(col_, this, static_cast<GUI::ListViewItem*>(item_), asc_);
- return res == 0 ? KListViewItem::compare(item_, col_, asc_) : res;
+ return res == 0 ? TDEListViewItem::compare(item_, col_, asc_) : res;
}
int ListViewItem::compareWeight(TQListViewItem* item_, int col_, bool asc_) const {
@@ -288,13 +288,13 @@ void ListViewItem::setSelected(bool s_) {
}
if(s_ != isSelected()) {
lv->updateSelected(this, s_);
- KListViewItem::setSelected(s_);
+ TDEListViewItem::setSelected(s_);
}
}
TQColor ListViewItem::backgroundColor(int column_) {
#if KDE_IS_VERSION(3,3,90)
- return KListViewItem::backgroundColor(column_);
+ return TDEListViewItem::backgroundColor(column_);
#else
ListView* view = listView();
if(view->columns() > 1 && view->shadeSortColumn() && column_ == view->sortColumn()) {
@@ -307,7 +307,7 @@ TQColor ListViewItem::backgroundColor(int column_) {
void ListViewItem::paintCell(TQPainter* p_, const TQColorGroup& cg_,
int column_, int width_, int align_) {
// taken from klistview.cpp
// I can't call KListViewItem::paintCell since KListViewItem::backgroundCOlor(int) is
// not virtual. I need to be sure to call ListViewItem::backgroundColor(int);
TQColorGroup cg = cg_;
const TQPixmap* pm = listView()->viewport()->backgroundPixmap();
@@ -321,7 +321,7 @@ void ListViewItem::paintCell(TQPainter* p_, const TQColorGroup& cg_,
backgroundColor(column_));
}
// don't call KListViewItem::paintCell() since that also does alternate painting, etc...
TQListViewItem::paintCell(p_, cg, column_, width_, align_);
// borrowed from amarok, draw line to left of cell
@@ -307,7 +307,7 @@ TQColor ListViewItem::backgroundColor(int column_) {
int column_, int width_, int align_) {
// taken from klistview.cpp
- // I can't call KListViewItem::paintCell since KListViewItem::backgroundCOlor(int) is
+ // I can't call TDEListViewItem::paintCell since TDEListViewItem::backgroundCOlor(int) is
// not virtual. I need to be sure to call ListViewItem::backgroundColor(int);
TQColorGroup cg = cg_;
@@ -321,7 +321,7 @@ void ListViewItem::paintCell(TQPainter* p_, const TQColorGroup& cg_,
backgroundColor(column_));
}
- // don't call KListViewItem::paintCell() since that also does alternate painting, etc...
+ // don't call TDEListViewItem::paintCell() since that also does alternate painting, etc...
TQListViewItem::paintCell(p_, cg, column_, width_, align_);
// borrowed from amarok, draw line to left of cell